@@ -3,7 +3,9 @@
 # Configured-by; disabled, no point in leaking usernames
 define cf_by ''
 define cf_email ''
-define cf_time ''
+define cf_time 'undisclosed-time'
+# cpan/Config-Perl-V/t/10_base.t does check cf_time indirectly
+# *and* cannot handle empty value there.
 
 # No need to leak these either
 define perladmin 'nobody@nowhere.land'
@@ -165,7 +167,6 @@ define d_portable 'define'
 define d_voidtty 'define'
 define d_semctl_semid_ds 'define'
 define d_semctl_semun 'define'
-define default_inc_excludes_dot 'undef'
 
 define d_msg_ctrunc 'undef'
 define d_msg_dontroute 'undef'
@@ -352,6 +353,9 @@ define to ':'
 define usrinc
 define versiononly 'undef'
 define xlibpth ''
+# cperl
+define sysincpth ''
+define syslibpth ''
 
 # Deprecated symbols
 define exe_ext ''
